"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require(".");
const decorationRegExp = /^(.*?)\[([!"#%&'()*+,-./{|}<>_~]+) ((?:\[[^\]]+\]|[^\]])+)\](.*)$/;
const createDecorationNode = (decoChars, nodes) => {
    const decoSet = new Set(decoChars);
    if (decoSet.has('*')) {
        const asteriskCount = decoChars.split('*').length - 1;
        decoSet.delete('*');
        decoSet.add(`*-${Math.min(asteriskCount, 10)}`);
    }
    return {
        type: 'decoration',
        decos: Array.from(decoSet),
        nodes
    };
};
exports.DecorationNodeParser = (text, { nested, quoted }, next) => {
    if (nested)
        return next();
    const decorationMatch = text.match(decorationRegExp);
    if (!decorationMatch)
        return next();
    const [, left, decoChars, target, right] = decorationMatch;
    return [
        ..._1.convertToLineNodes(left, { nested, quoted }),
        createDecorationNode(decoChars, _1.convertToLineNodes(target, { nested: true, quoted })),
        ..._1.convertToLineNodes(right, { nested, quoted })
    ];
};
//# sourceMappingURL=DecorationNode.js.map